==> sqlconstructor-1.0.42.tar.gz: sqlconstructor-1.0.42/src/sqlconstructor/constants.py <==
# coding=utf-8
"""Constants"""

__author__ = 'https://github.com/akvilary'

# if you want statements be separated by comma by default then add section keyword here
SECTIONS_WITH_COMMA_SEPARATOR = (
    'SELECT',
    'FROM',
    'SET',
    'VALUES',
    'ORDER BY',
    'GROUP BY',
    'JSON_OBJECT_AGG',
    'COALESCE',
)

# all SQLL keywords to make them uppercase in SQL text
SQL_KEYWORDS = (
    'ALL',
    'ANALYSE',
    'ANALYZE',
    'AND',
    'ANY',
    'ARRAY',
    'ARRAY_AGG',
    'AS',
    'ASC',
    'ASYMMETRIC',
    'AUTHORIZATION',
    'BEGIN',
    'BETWEEN',
    'BINARY',
    'BOTH',
    'BY',
    'CARDINALITY',
    'CASCADE',
    'CASE',
    'CAST',
    'CHECK',
    'COLLATE',
    'COLLATION',
    'COLUMN',
    'COMMIT',
    'CONCURRENTLY',
    'CONFLICT',
    'CONSTRAINT',
    'COUNT',
    'CREATE',
    'CROSS',
    'CURRENT_CATALOG',
    'CURRENT_DATE',
    'CURRENT_ROLE',
    'CURRENT_SCHEMA',
    'CURRENT_TIME',
    'CURRENT_TIMESTAMP',
    'CURRENT_USER',
    'CURSOR',
    'DEFAULT',
    'DEFERRABLE',
    'DELETE',
    'DESC',
    'DISTINCT',
    'DO',
    'ELSE',
    'END',
    'EXCEPT',
    'EXISTS',
    'EXPLAIN',
    'FALSE',
    'FETCH',
    'FOR',
    'FOREIGN',
    'FREEZE',
    'FROM',
    'FULL',
    'FUNCTION',
    'GRANT',
    'GROUP',
    'HAVING',
    'ILIKE',
    'IN',
    'INDEX',
    'INITIALLY',
    'INNER',
    'INSERT',
    'INTERSECT',
    'INTO',
    'IS',
    'ISNULL',
    'JOIN',
    'JSON_ARRAY',
    'JSON_ARRAYAGG',
    'JSON_EXISTS',
    'JSON_OBJECT',
    'JSON_OBJECTAGG',
    'JSON_QUERY',
    'JSON_TABLE',
    'JSON_TABLE_PRIMITIVE',
    'JSON_VALUE',
    'LATERAL',
    'LEADING',
    'LEFT',
    'LIKE',
    'LIMIT',
    'LOCALTIME',
    'LOCALTIMESTAMP',
    'MAX',
    'MIN',
    'NATURAL',
    'NOT',
    'NOTNULL',
    'NULL',
    'NULLIF',
    'OFFSET',
    'ON',
    'ONLY',
    'OR',
    'ORDER',
    'OUTER',
    'OVER',
    'OVERLAPS',
    'PLACING',
    'PRIMARY',
    'REFERENCES',
    'RETURN',
    'RETURNING',
    'RIGHT',
    'ROLLBACK',
    'SELECT',
    'SESSION_USER',
    'SET',
    'SIMILAR',
    'SOME',
    'SYMMETRIC',
    'TABLE',
    'TABLESAMPLE',
    'THEN',
    'TO',
    'TRAILING',
    'TRIGGER',
    'TRUE',
    'UNION',
    'UNIQUE',
    'UNNEST',
    'UNTIL',
    'USER',
    'USING',
    'VACUUM',
    'VALUES',
    'VARIADIC',
    'VERBOSE',
    'WHEN',
    'WHERE',
    'WINDOW',
    'WITH',
)

==> sqlconstructor-1.2.5.tar.gz: sqlconstructor-1.2.5/src/sqlconstructor/constants.py <==
# coding=utf-8
"""Constants"""

__author__ = 'https://github.com/akvilary'

# default indentation for sql body of SqlSection
DEFAULT_IND = 2

# for filters
AND_MODE = 'AND'
OR_MODE = 'OR'

# if you want statements be separated by comma by default then add section keyword here
SECTIONS_WITH_COMMA_SEPARATOR = (
    'SELECT',
    'FROM',
    'SET',
    'VALUES',
    'ORDER BY',
    'GROUP BY',
    'JSON_OBJECT_AGG',
    'COALESCE',
)

# all SQLL keywords to make them uppercase in SQL text
SQL_KEYWORDS = (
    'ALL',
    'ANALYSE',
    'ANALYZE',
    'AND',
    'ANY',
    'ARRAY',
    'ARRAY_AGG',
    'AS',
    'ASC',
    'ASYMMETRIC',
    'AUTHORIZATION',
    'BEGIN',
    'BETWEEN',
    'BINARY',
    'BOTH',
    'BY',
    'CARDINALITY',
    'CASCADE',
    'CASE',
    'CAST',
    'CHECK',
    'COLLATE',
    'COLLATION',
    'COLUMN',
    'COMMIT',
    'CONCURRENTLY',
    'CONFLICT',
    'CONSTRAINT',
    'COUNT',
    'CREATE',
    'CROSS',
    'CURRENT_CATALOG',
    'CURRENT_DATE',
    'CURRENT_ROLE',
    'CURRENT_SCHEMA',
    'CURRENT_TIME',
    'CURRENT_TIMESTAMP',
    'CURRENT_USER',
    'CURSOR',
    'DEFAULT',
    'DEFERRABLE',
    'DELETE',
    'DESC',
    'DISTINCT',
    'DO',
    'ELSE',
    'END',
    'EXCEPT',
    'EXISTS',
    'EXPLAIN',
    'FALSE',
    'FETCH',
    'FOR',
    'FOREIGN',
    'FREEZE',
    'FROM',
    'FULL',
    'FUNCTION',
    'GRANT',
    'GROUP',
    'HAVING',
    'ILIKE',
    'IN',
    'INDEX',
    'INITIALLY',
    'INNER',
    'INSERT',
    'INTERSECT',
    'INTO',
    'IS',
    'ISNULL',
    'JOIN',
    'JSON_ARRAY',
    'JSON_ARRAYAGG',
    'JSON_EXISTS',
    'JSON_OBJECT',
    'JSON_OBJECTAGG',
    'JSON_QUERY',
    'JSON_TABLE',
    'JSON_TABLE_PRIMITIVE',
    'JSON_VALUE',
    'LATERAL',
    'LEADING',
    'LEFT',
    'LIKE',
    'LIMIT',
    'LOCALTIME',
    'LOCALTIMESTAMP',
    'MAX',
    'MIN',
    'NATURAL',
    'NOT',
    'NOTNULL',
    'NULL',
    'NULLIF',
    'OFFSET',
    'ON',
    'ONLY',
    'OR',
    'ORDER',
    'OUTER',
    'OVER',
    'OVERLAPS',
    'PLACING',
    'PRIMARY',
    'REFERENCES',
    'RETURN',
    'RETURNING',
    'RIGHT',
    'ROLLBACK',
    'SELECT',
    'SESSION_USER',
    'SET',
    'SIMILAR',
    'SOME',
    'SYMMETRIC',
    'TABLE',
    'TABLESAMPLE',
    'THEN',
    'TO',
    'TRAILING',
    'TRIGGER',
    'TRUE',
    'UNION',
    'UNIQUE',
    'UNNEST',
    'UNTIL',
    'USER',
    'USING',
    'VACUUM',
    'VALUES',
    'VARIADIC',
    'VERBOSE',
    'WHEN',
    'WHERE',
    'WINDOW',
    'WITH',
)
